Models Documentation
====================

AI Models
====================
.. automodule:: endoreg_db.models.administration.ai
   :members:
   :undoc-members:
   :show-inheritance:


Case
====================
.. automodule:: endoreg_db.models.administration.case
   :members:
   :undoc-members:
   :show-inheritance:


Center
====================
.. automodule:: endoreg_db.models.administration.center
   :members:
   :undoc-members:
   :show-inheritance:


Person
====================
.. automodule:: endoreg_db.models.administration.person
   :members:
   :undoc-members:
   :show-inheritance:

Product
====================
.. automodule:: endoreg_db.models.administration.person
   :members:
   :undoc-members:
   :show-inheritance:

Label
====================
.. automodule:: endoreg_db.models.label
   :members:
   :undoc-members:
   :show-inheritance:

Video
====================
.. automodule:: endoreg_db.models.media.video
   :members:
   :undoc-members:
   :show-inheritance:

Frame
====================
.. automodule:: endoreg_db.models.media.frame
   :members:
   :undoc-members:
   :show-inheritance:

Report
====================
.. automodule:: endoreg_db.models.media.pdf
   :members:
   :undoc-members:
   :show-inheritance:

Disease
====================
.. automodule:: endoreg_db.models.medical.disease
   :members:
   :undoc-members:
   :show-inheritance:

Event
====================
.. automodule:: endoreg_db.models.medical.event
   :members:
   :undoc-members:
   :show-inheritance:

Patient
====================
.. automodule:: endoreg_db.models.medical.patient
   :members:
   :undoc-members:
   :show-inheritance:

Finding
====================
.. automodule:: endoreg_db.models.medical.finding
   :members:
   :undoc-members:
   :show-inheritance:

Risk
====================
.. automodule:: endoreg_db.models.medical.risk
   :members:
   :undoc-members:
   :show-inheritance:

Hardware
====================
.. automodule:: endoreg_db.models.medical.hardware
   :members:
   :undoc-members:
   :show-inheritance:

Laboratory
====================
.. automodule:: endoreg_db.models.medical.laboratory
   :members:
   :undoc-members:
   :show-inheritance:

Organ
====================
.. automodule:: endoreg_db.models.medical.organ
   :members:
   :undoc-members:
   :show-inheritance:

Metadata
====================
.. automodule:: endoreg_db.models.metadata
   :members:
   :undoc-members:
   :show-inheritance:

Requirement
====================
.. automodule:: endoreg_db.models.requirement
   :members:
   :undoc-members:
   :show-inheritance:

State
====================
.. automodule:: endoreg_db.models.state
   :members:
   :undoc-members:
   :show-inheritance:

Other
====================
.. automodule:: endoreg_db.models.other
   :members:
   :undoc-members:
   :show-inheritance: